var searchPane = {
	//clear
	delayedClearLabel: null,
	delayedClearInput: null,
	delayedClearUnits: null,
	cancelClearCbox: null,
	//reset
	engineMenu: null,
	enginePopup: null,
	delayedResetLabel: null,
	delayedResetInput: null,
	delayedResetUnits: null,
	cancelResetCbox: null,
	//tabs
	detectionLabel: null,
	blankTabCbox: null,
	homeTabCbox: null,
	
	buildEngineList: function()
	{
		var version = 0;
		try{
			Components.classes["@mozilla.org/browser/search-service;1"]
				.getService(Components.interfaces.nsIBrowserSearchService);
			version = 2;
		}catch(ex){
			version = 1;
		}
		
		const kXULNS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
		var defaultEnginePref = document.getElementById("extensions.searchload.defaultengine");
		var enginesExist = false;
		var engineWasFound = false;
		
		if(version===2)
		{
			var searchService = Components.classes["@mozilla.org/browser/search-service;1"]
								.getService(Components.interfaces.nsIBrowserSearchService);
			var engines = searchService.getVisibleEngines({ });
		}
		else if(version===1)
		{
			var rdfService = Components.classes["@mozilla.org/rdf/rdf-service;1"]
						   .getService(Components.interfaces.nsIRDFService);
			var internetSearchDS = rdfService.GetDataSource("rdf:internetsearch");
			const kNC_Root  = rdfService.GetResource("NC:SearchEngineRoot");
			const kNC_child = rdfService.GetResource("http://home.netscape.com/NC-rdf#child");
			const kNC_Name  = rdfService.GetResource("http://home.netscape.com/NC-rdf#Name");
			const kNC_Icon  = rdfService.GetResource("http://home.netscape.com/NC-rdf#Icon");
			var arcs = internetSearchDS.GetTargets(kNC_Root, kNC_child, true);
			var engines = new Array;
			var index=0;
			while(arcs.hasMoreElements()){
				var rEngine = arcs.getNext().QueryInterface(Components.interfaces.nsIRDFResource);
				var target = internetSearchDS.GetTarget(rEngine, kNC_Name, true);
				var engineName = target.QueryInterface(Components.interfaces.nsIRDFLiteral).Value;
				target = internetSearchDS.GetTarget(rEngine, kNC_Icon, true);
				var engineIcon = target.QueryInterface(Components.interfaces.nsIRDFLiteral).Value;
				engines[index++] = {name:engineName,iconURI:{spec:engineIcon}};
			}
		}
		
		if(engines.length > 0)
		{
			enginesExist = true;
			for(var i=0; i < engines.length; i++)
			{
				var menuitem = document.createElementNS(kXULNS, "menuitem");
				menuitem.setAttribute("label", engines[i].name);
				menuitem.setAttribute("value", engines[i].name);
				menuitem.setAttribute("class", "menuitem-iconic engine-icon");
				menuitem.setAttribute("src", engines[i].iconURI.spec);
				this.enginePopup.appendChild(menuitem);
				if(engines[i].name == defaultEnginePref.value)
				{
					this.engineMenu.selectedIndex = i;
					engineWasFound = true;
				}
			}
		}
		if(enginesExist && !engineWasFound)
			defaultEnginePref.valueFromPreferences = engines[0].name;
	},//buildEngineList
	
	init: function()
	{
		this.delayedClearLabel = document.getElementById("delayedclear-label");
		this.delayedClearInput = document.getElementById("delayedclear-input");
		this.delayedClearUnits = document.getElementById("delayedclear-units");
		this.cancelClearCbox = document.getElementById("cancelclear-checkbox");
		
		this.engineMenu  = document.getElementById("engine-menu");
		this.enginePopup = document.getElementById("engine-popup");
		this.delayedResetLabel = document.getElementById("delayedreset-label");
		this.delayedResetInput = document.getElementById("delayedreset-input");
		this.delayedResetUnits = document.getElementById("delayedreset-units");
		this.cancelResetCbox = document.getElementById("cancelreset-checkbox");
		
		this.detectionLabel = document.getElementById("detection-label");
		this.blankTabCbox = document.getElementById("detectblank-checkbox");
		this.homeTabCbox  = document.getElementById("detecthome-checkbox");
		
		try{
			this.buildEngineList();
		}catch(engines_error){}
		
		var clearSearchBarPref = document.getElementById("extensions.searchload.clearonsearch");
		var resetSearchBarPref = document.getElementById("extensions.searchload.resetonsearch");
		var tabcontrolPref     = document.getElementById("extensions.searchload.newtab");
		
		this.updateDetect(tabcontrolPref.value);
		this.updateClearStatus(clearSearchBarPref.value);
		this.updateResetStatus(resetSearchBarPref.value);
	},//init
	
	updateClearStatus: function(boolVal)
	{
		var clearDelayPref = document.getElementById("extensions.searchload.cleardelay");
		this.delayedClearLabel.disabled = !boolVal;
		this.delayedClearInput.disabled = !boolVal;
		this.delayedClearUnits.disabled = !boolVal;
		this.updateCancelClear( clearDelayPref.value===0 || !boolVal);
	},
	
	updateCancelClear: function(disable)
	{
		if(disable)
			this.cancelClearCbox.disabled = true;
		else
			this.cancelClearCbox.disabled = false;
	},
	
	updateResetStatus: function(boolVal)
	{
		var resetDelayPref = document.getElementById("extensions.searchload.resetdelay");
		this.engineMenu.disabled = !boolVal;
		this.delayedResetLabel.disabled = !boolVal;
		this.delayedResetInput.disabled = !boolVal;
		this.delayedResetUnits.disabled = !boolVal;
		this.updateCancelReset( resetDelayPref.value===0 || !boolVal);
	},
	
	updateCancelReset: function(disable)
	{
		if(disable)
			this.cancelResetCbox.disabled = true;
		else
			this.cancelResetCbox.disabled = false;
	},
	
	updateDetect: function(index)
	{
		if(index===0)
		{	this.detectionLabel.disabled = true;
			this.blankTabCbox.disabled = true;
			this.homeTabCbox.disabled = true;
		}
		else
		{	this.detectionLabel.disabled = false;
			this.blankTabCbox.disabled = false;
			this.homeTabCbox.disabled = false;
		}
	}
};